EasyExtend.langlets.p4d.bytelet.ByteletList

Package EasyExtend :: Package langlets :: Package p4d :: Module bytelet :: Class ByteletList |
[hide private]
[frames] | no frames]

# Class ByteletList

     object --+
              |
           list --+
                  |
    p4dbase.P4DList --+
                      |
                     ByteletList

Class used to represent lists of P4D objects. A special property of P4DList objects is the provisioning of P4D object methods for P4DLists containing a single P4D element.

So P4DList([a]).m() == a.m() for P4D methods like child(), comment(), text() etc.

Instance Methods | [hide private]
hex(self) |
clone(self) |
Inherited from `p4dbase.P4DList`: `CDATA`, `__delitem__`, `__getattr__`, `__setattr__`, `attribute`, `attributes`, `child`, `children`, `comment`, `content`, `first_child`, `get`, `p4dstr`, `search`, `text`, `update`, `xmlstr` Inherited from `p4dbase.P4DList` (private): `_get_tag` Inherited from `list`: `__add__`, `__contains__`, `__delslice__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__gt__`, `__hash__`, `__iadd__`, `__imul__`, `__init__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__new__`, `__repr__`, `__reversed__`, `__rmul__`, `__setitem__`, `__setslice__`, `append`, `count`, `extend`, `index`, `insert`, `pop`, `remove`, `reverse`, `sort` Inherited from `object`: `__delattr__`, `__reduce__`, `__reduce_ex__`, `__str__`

Properties | [hide private]
Inherited from `p4dbase.P4DList`: `tag` Inherited from `object`: `__class__`